BoundUpsert

Struct BoundUpsert 

pub struct BoundUpsert {
    pub constraint: UpsertConstraint,
    pub assignments: Vec<BoundAssignment>,
    pub do_update: bool,
    pub filter: Option<BoundExpr>,
    pub triggers: Vec<BoundTrigger>,
}
A bound ON CONFLICT ... DO UPDATE clause.

Fields

constraint: UpsertConstraint

The constraint the clause’s conflict target names.

assignments: Vec<BoundAssignment>

The assignments, or empty for DO NOTHING.

do_update: bool

Whether the action is DO UPDATE.

filter: Option<BoundExpr>

The WHERE on the DO UPDATE.

triggers: Vec<BoundTrigger>

The UPDATE triggers the clause fires, and the foreign key checks an update of the assigned columns needs. Empty for DO NOTHING.