pub enum ForeignKeyEvent {
ChildInsert,
ChildUpdate,
ParentDelete,
ParentUpdate,
}Expand description
Which write a synthesised trigger is generated for.
Variants
ChildInsert
A row is being added to the child table.
ChildUpdate
A row of the child table is being changed.
ParentDelete
A row is being taken out of the parent table.
ParentUpdate
A row of the parent table is being changed.