pub fn aggregate_arity_ok(func: AggregateFunc, count: usize, star: bool) -> boolExpand description
Returns whether an argument count is legal for an aggregate.
pub fn aggregate_arity_ok(func: AggregateFunc, count: usize, star: bool) -> boolReturns whether an argument count is legal for an aggregate.