pub struct BoundResultColumn {
pub expr: BoundExpr,
pub name: Vec<u8>,
pub origin: Option<(Vec<u8>, Vec<u8>, Vec<u8>)>,
pub declared_type: Vec<u8>,
}Expand description
One result column, after star expansion.
Fields
expr: BoundExprThe expression.
name: Vec<u8>The name the column reports.
origin: Option<(Vec<u8>, Vec<u8>, Vec<u8>)>The table the column came from, when it came from one.
declared_type: Vec<u8>The declared type the column reports, when it has one.