pub struct ParseError {
pub kind: ParseErrorKind,
pub span: Span,
}Expand description
A parse failure with its location.
Fields
kind: ParseErrorKindWhy it failed.
span: SpanWhere it failed.
Implementations
Sourceimpl ParseError
impl ParseError
Sourcepub fn new(kind: ParseErrorKind, span: Span) -> ParseError
pub fn new(kind: ParseErrorKind, span: Span) -> ParseError
Returns a failure at a span.
Sourcepub fn code(&self) -> PrimaryCode
pub fn code(&self) -> PrimaryCode
Returns the stable result code this failure reports as.
A syntax error is SQLITE_ERROR, which is what the pinned release
returns from prepare. A limit is SQLITE_TOOBIG where SQLite uses it
and SQLITE_ERROR where SQLite reports the limit as a parse error,
which is the case for parser depth and compound depth.