pub fn calls_a_volatile_function(expr: &BoundExpr) -> bool
Reports whether an expression calls a function whose answer changes from one call to the next, such as random().
random()
@param expr - the expression, or a part of it