pub enum Change {
Delete(Value<'static>),
Insert {
rowid: Value<'static>,
values: Vec<Value<'static>>,
},
Update {
old_rowid: Value<'static>,
new_rowid: Value<'static>,
values: Vec<Value<'static>>,
},
}Expand description
One row a write asks a module to make.
Variants
Delete(Value<'static>)
Remove the row with this rowid or primary key.
Insert
Add a row.
Fields
Update
Replace a row.